export type UseDebugConcurrentParameters = {
    /**
     * Runs when the first render starts.
     *
     * The first render may either be
     * a low priority render or a high
     * priority render, but this cannot
     * be inferred from the inside,
     * only from the outside.
     */
    onFirstRenderStart?: () => void;
    /**
     * Runs when the first render ends.
     */
    onFirstRenderEnd?: () => void;
    /**
     * Runs when a low priority render starts.
     */
    onLowPriorityStart?: () => void;
    /**
     * Runs when a low priority render ends.
     */
    onLowPriorityEnd?: () => void;
    /**
     * Runs when a high priority render starts.
     *
     * When a high prioirity render starts
     * before a previously started low priority
     * has the chance to end, this means
     * that the low priority render was
     * interrupted.
     */
    onHighPriorityStart?: () => void;
    /**
     * Runs when a high priority render ends.
     */
    onHighPriorityEnd?: () => void;
};
/**
 * Used to debug React's concurrent features,
 * more specifically, it allows you to
 * attach callbacks to the lifecycle of
 * low priority and high priority renders.
 *
 * To make your results as accurate as possible,
 * make sure this hook is the first hook in your
 * component.
 */
export declare const useDebugConcurrent: ({ onFirstRenderStart, onFirstRenderEnd, onLowPriorityStart, onLowPriorityEnd, onHighPriorityStart, onHighPriorityEnd, }: UseDebugConcurrentParameters) => void;
